@@ -1,7 +1,6 @@
 
 import os
 import binwalk
-from nose.tools import eq_, ok_
 
 def test_firmware_jffs2():
     '''
@@ -18,25 +17,25 @@ def test_firmware_jffs2():
                                quiet=True)
 
     # Test number of modules used
-    eq_(len(scan_result), 1)
+    assert len(scan_result) == 1
 
     # Test number of results for that module, should be more than one
-    ok_(len(scan_result[0].results) > 1)
+    assert len(scan_result[0].results) > 1
 
     first_result = scan_result[0].results[0]
 
     # Check the offset of the first result
-    eq_(first_result.offset, 0)
+    assert first_result.offset == 0
 
     # Make sure we found the jffs file system
-    ok_(first_result.description.startswith("JFFS2 filesystem"))
+    assert first_result.description.startswith("JFFS2 filesystem")
 
     # Check to make sure the first result was displayed
-    ok_(first_result.display == True)
+    assert first_result.display == True
 
     # Make sure we only found jffs2 file system entries
     # and that nothing but the first entry was displayed
     for result in scan_result[0].results[1:]:
-        ok_(result.description.startswith("JFFS2 filesystem"))
-        ok_(result.display == False)
+        assert result.description.startswith("JFFS2 filesystem")
+        assert result.display == False
 
